# Sidetrek Python Client internal docs

## Deployment

0. Initial deployment only - configure pypi https://python-poetry.org/docs/repositories/#configuring-credentials
1. `poetry version <NEW_VERSION>`
2. `poetry publish --build`